@@ -44,7 +44,7 @@ public:
     ScreenShotEffect();
     ~ScreenShotEffect() override;
 
-    void paintScreen(int mask, QRegion region, ScreenPaintData &data) override;
+    void paintScreen(int mask, const QRegion &region, ScreenPaintData &data) override;
     void postPaintScreen() override;
     bool isActive() const override;
 
